Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DeployStrategy ¶
type DeployStrategy string
DeployStrategy enumerates different ways of deploying kube-fledged control plane
const ( //DeployUsingYaml may be used with a controlplane.HandlerConfig to install using YAML manifests DeployUsingYaml DeployStrategy = "yaml" //DeployUsingHelmChart may be used with a controlplane.HandlerConfig to install using the helm chart files DeployUsingHelmChart DeployStrategy = "helm-chart" //DeployUsingOperator may be used with a controlplane.HandlerConfig to install using the helm operator DeployUsingOperator DeployStrategy = "operator" )
type Handler ¶
type Handler struct {
CreateFn func(context.Context) error
IsCreated func(context.Context) bool
DeleteFn func(context.Context) error
IsDeleted func(context.Context) bool
}
Handler is an intermittent object during control plane creation/deletion. This abstracts away the installation and deletion complexities
func NewHandler ¶
func NewHandler(t *testing.T, config HandlerConfig) *Handler
NewHandler returns a Create-able and Delete-able object
type HandlerConfig ¶
type HandlerConfig struct {
Strategy DeployStrategy
YamlDir string
HelmChartDir string
OperatorDir string
TestEnvConfig *envconf.Config
Namespace string
OperatorNamespace string
EnableWebhookServer bool
// contains filtered or unexported fields
}
HandlerConfig is a config for the kube-fledged control plane
Click to show internal directories.
Click to hide internal directories.