Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ImageCacheLister ¶
type ImageCacheLister interface {
// List lists all ImageCaches in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ImageCache, err error)
// ImageCaches returns an object that can list and get ImageCaches.
ImageCaches(namespace string) ImageCacheNamespaceLister
ImageCacheListerExpansion
}
ImageCacheLister helps list ImageCaches. All objects returned here must be treated as read-only.
func NewImageCacheLister ¶
func NewImageCacheLister(indexer cache.Indexer) ImageCacheLister
NewImageCacheLister returns a new ImageCacheLister.
type ImageCacheListerExpansion ¶
type ImageCacheListerExpansion interface{}
ImageCacheListerExpansion allows custom methods to be added to ImageCacheLister.
type ImageCacheNamespaceLister ¶
type ImageCacheNamespaceLister interface {
// List lists all ImageCaches in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha2.ImageCache, err error)
// Get retrieves the ImageCache from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha2.ImageCache, error)
ImageCacheNamespaceListerExpansion
}
ImageCacheNamespaceLister helps list and get ImageCaches. All objects returned here must be treated as read-only.
type ImageCacheNamespaceListerExpansion ¶
type ImageCacheNamespaceListerExpansion interface{}
ImageCacheNamespaceListerExpansion allows custom methods to be added to ImageCacheNamespaceLister.
Click to show internal directories.
Click to hide internal directories.